==> forestry_1.12.2-5.6.0.199-sources.jar: forestry/core/circuits/Circuits.java <==
package forestry.core.circuits;

import forestry.api.circuits.ICircuit;

@SuppressWarnings({"unused", "NullableProblems"})
public class Circuits {
	public static ICircuit energyElectricChoke1;
	public static ICircuit energyElectricEfficiency1;
	public static ICircuit energyElectricBoost1;
	public static ICircuit energyElectricBoost2;
	public static ICircuit farmArborealManaged;
	public static ICircuit farmShroomManaged;
	public static ICircuit farmCerealManaged;
	public static ICircuit farmVegetableManaged;
	public static ICircuit farmPeatManaged;
	public static ICircuit farmSucculentManaged;
	public static ICircuit farmPoaleManaged;
	public static ICircuit farmFungal;
	public static ICircuit farmInfernalManaged;
	public static ICircuit farmGourdManaged;
	public static ICircuit farmShroomManual;
	public static ICircuit farmCerealManual;
	public static ICircuit farmVegetableManual;
	public static ICircuit farmPeatManual;
	public static ICircuit farmSucculentManual;
	public static ICircuit farmPoalesManual;
	public static ICircuit farmGourdManual;
	public static ICircuit farmCocoaManual;
	public static ICircuit farmOrchardManual;
	public static ICircuit farmRubberManual;
	public static ICircuit farmEnderManaged;
	public static ICircuit farmOrchidManaged;
	public static ICircuit machineSpeedUpgrade1;
	public static ICircuit machineSpeedUpgrade2;
	public static ICircuit machineEfficiencyUpgrade1;
	public static ICircuit climatiserTemperature1;
	public static ICircuit climatiserTemperature2;
	public static ICircuit climatiserHumidity1;
	public static ICircuit climatiserHumidity2;
}

==> forestry_1.12.2-5.8.0.248-sources.jar: forestry/core/circuits/Circuits.java <==
package forestry.core.circuits;

import forestry.api.circuits.ICircuit;

@SuppressWarnings({"unused", "NullableProblems"})
public class Circuits {
	public static ICircuit energyElectricChoke1;
	public static ICircuit energyElectricEfficiency1;
	public static ICircuit energyElectricBoost1;
	public static ICircuit energyElectricBoost2;

	public static ICircuit farmArborealManaged;
	public static ICircuit farmOrchardManaged;
	public static ICircuit farmShroomManaged;
	public static ICircuit farmCropsManaged;
	public static ICircuit farmPeatManaged;
	public static ICircuit farmSucculentManaged;
	public static ICircuit farmPoalesManaged;
	public static ICircuit farmInfernalManaged;
	public static ICircuit farmEnderManaged;
	public static ICircuit farmOrchidManaged;
	public static ICircuit farmGourdManaged;
	public static ICircuit farmCocoaManaged;


	public static ICircuit farmArborealManual;
	public static ICircuit farmOrchardManual;
	public static ICircuit farmShroomManual;
	public static ICircuit farmCropsManual;
	public static ICircuit farmPeatManual;
	public static ICircuit farmSucculentManual;
	public static ICircuit farmPoalesManual;
	public static ICircuit farmInfernalManual;
	public static ICircuit farmEnderManual;
	public static ICircuit farmOrchidManual;
	public static ICircuit farmGourdManual;
	public static ICircuit farmCocoaManual;
	public static ICircuit farmRubberManual;

	public static ICircuit machineSpeedUpgrade1;
	public static ICircuit machineSpeedUpgrade2;
	public static ICircuit machineEfficiencyUpgrade1;

	public static ICircuit climatiserTemperature1;
	public static ICircuit climatiserTemperature2;
	public static ICircuit climatiserHumidity1;
	public static ICircuit climatiserHumidity2;
}
